

make naming conventions (kiocb versus iocb) clearer.


 fs/aio.c |   34 +++++++++++++++++-----------------
 1 files changed, 17 insertions(+), 17 deletions(-)

diff -puN fs/aio.c~aio-01-retry-cleanup fs/aio.c
--- 25/fs/aio.c~aio-01-retry-cleanup	2003-05-18 18:15:28.000000000 -0700
+++ 25-akpm/fs/aio.c	2003-05-18 18:16:05.000000000 -0700
@@ -581,7 +581,7 @@ static ssize_t aio_run_iocb(struct kiocb
 	ssize_t ret;
 
 	if (iocb->ki_retried++ > 1024*1024) {
-		printk("Maximal retry count. Bytes done %d\n",
+		printk("Maximal retry count.  Bytes done %Zd\n",
 			iocb->ki_nbytes - iocb->ki_left);
 		return -EAGAIN;
 	}
@@ -1081,7 +1081,7 @@ asmlinkage long sys_io_destroy(aio_conte
 	return -EINVAL;
 }
 
-ssize_t aio_pread(struct kiocb *iocb)
+static ssize_t aio_pread(struct kiocb *iocb)
 {
 	struct file *file = iocb->ki_filp;
 	ssize_t ret = 0;
@@ -1108,7 +1108,7 @@ ssize_t aio_pread(struct kiocb *iocb)
 	return ret;
 }
 
-ssize_t aio_pwrite(struct kiocb *iocb)
+static ssize_t aio_pwrite(struct kiocb *iocb)
 {
 	struct file *file = iocb->ki_filp;
 	ssize_t ret = 0;
@@ -1137,7 +1137,7 @@ ssize_t aio_pwrite(struct kiocb *iocb)
 	return ret;
 }
 
-ssize_t aio_fdsync(struct kiocb *iocb)
+static ssize_t aio_fdsync(struct kiocb *iocb)
 {
 	struct file *file = iocb->ki_filp;
 	ssize_t ret = -EINVAL;
@@ -1147,7 +1147,7 @@ ssize_t aio_fdsync(struct kiocb *iocb)
 	return ret;
 }
 	
-ssize_t aio_fsync(struct kiocb *iocb)
+static ssize_t aio_fsync(struct kiocb *iocb)
 {
 	struct file *file = iocb->ki_filp;
 	ssize_t ret = -EINVAL;
@@ -1158,52 +1158,52 @@ ssize_t aio_fsync(struct kiocb *iocb)
 }
 	
 /* Called during initial submission and subsequent retry operations */
-ssize_t aio_setup_iocb(struct kiocb *iocb)
+ssize_t aio_setup_iocb(struct kiocb *kiocb)
 {
-	struct file *file = iocb->ki_filp;
+	struct file *file = kiocb->ki_filp;
 	ssize_t ret = 0;
 	
-	switch (iocb->ki_opcode) {
+	switch (kiocb->ki_opcode) {
 	case IOCB_CMD_PREAD:
 		ret = -EBADF;
 		if (unlikely(!(file->f_mode & FMODE_READ)))
 			break;
 		ret = -EFAULT;
-		if (unlikely(!access_ok(VERIFY_WRITE, iocb->ki_buf, 
-			iocb->ki_left)))
+		if (unlikely(!access_ok(VERIFY_WRITE, kiocb->ki_buf, 
+			kiocb->ki_left)))
 			break;
 		ret = -EINVAL;
 		if (file->f_op->aio_read)
-			iocb->ki_retry = aio_pread;
+			kiocb->ki_retry = aio_pread;
 		break;
 	case IOCB_CMD_PWRITE:
 		ret = -EBADF;
 		if (unlikely(!(file->f_mode & FMODE_WRITE)))
 			break;
 		ret = -EFAULT;
-		if (unlikely(!access_ok(VERIFY_READ, iocb->ki_buf, 
-			iocb->ki_left)))
+		if (unlikely(!access_ok(VERIFY_READ, kiocb->ki_buf, 
+			kiocb->ki_left)))
 			break;
 		ret = -EINVAL;
 		if (file->f_op->aio_write)
-			iocb->ki_retry = aio_pwrite;
+			kiocb->ki_retry = aio_pwrite;
 		break;
 	case IOCB_CMD_FDSYNC:
 		ret = -EINVAL;
 		if (file->f_op->aio_fsync)
-			iocb->ki_retry = aio_fdsync;
+			kiocb->ki_retry = aio_fdsync;
 		break;
 	case IOCB_CMD_FSYNC:
 		ret = -EINVAL;
 		if (file->f_op->aio_fsync)
-			iocb->ki_retry = aio_fsync;
+			kiocb->ki_retry = aio_fsync;
 		break;
 	default:
 		dprintk("EINVAL: io_submit: no operation provided\n");
 		ret = -EINVAL;
 	}
 
-	if (!iocb->ki_retry)
+	if (!kiocb->ki_retry)
 		return ret;
 
 	return 0;

_
